# UDGram
Compute probabilities in N-grams model for tags in UD format

### Instalation
  ...

### Usage
##### n-gram funcions
  - `bigram`  : function for bigrams with specify tag
  - `trigram` : function for trigrams with specify tag
  - `ngram`   : general function for ngram with specify tag

##### ngram matriz funcions
  - `bigram_matriz`	: matriz with bigram probabilities for tags
  - `ngram_matriz`	: matriz with ngram probabilities for tags


### Contributors
  - Wellington Silva [(@wellington36)](https://github.com/wellington36)
